@@ -33,7 +33,7 @@ async fn main() -> io::Result<()> {
     }]
     "#;
 
-    chewdata::exec(serde_json::from_str(config)?, None)
+    chewdata::exec(serde_json::from_str(config)?, None, None)
         .with_subscriber(subscriber)
         .await
 }
